==> kubernetes-model-apps-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetUpdateStrategyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StatefulSetUpdateStrategyFluentImpl<A extends io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent<A>{
  public StatefulSetUpdateStrategyFluentImpl() {
  }
  public StatefulSetUpdateStrategyFluentImpl(io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategy instance) {
    this.withRollingUpdate(instance.getRollingUpdate()); 
    this.withType(instance.getType()); 
  }
  private io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder rollingUpdate;
  private java.lang.String type;
  
  /**
   * This method has been deprecated, please use method buildRollingUpdate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy getRollingUpdate() {
    return this.rollingUpdate!=null?this.rollingUpdate.build():null;
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy buildRollingUpdate() {
    return this.rollingUpdate!=null?this.rollingUpdate.build():null;
  }
  public A withRollingUpdate(io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy rollingUpdate) {
    _visitables.get("rollingUpdate").remove(this.rollingUpdate);
    if (rollingUpdate!=null){ this.rollingUpdate= new io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder(rollingUpdate); _visitables.get("rollingUpdate").add(this.rollingUpdate);} return (A) this;
  }
  public java.lang.Boolean hasRollingUpdate() {
    return this.rollingUpdate != null;
  }
  public A withNewRollingUpdate(java.lang.Integer partition) {
    return (A)withRollingUpdate(new RollingUpdateStatefulSetStrategy(partition));
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate() {
    return new io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluentImpl.RollingUpdateNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy item) {
    return new io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluentImpl.RollingUpdateNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate() {
    return withNewRollingUpdateLike(getRollingUpdate());
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate() {
    return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy item) {
    return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StatefulSetUpdateStrategyFluentImpl that = (StatefulSetUpdateStrategyFluentImpl) o;
    if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rollingUpdate,  type,  super.hashCode());
  }
  public class RollingUpdateNestedImpl<N> extends io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyFluentImpl<io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>> implements io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    RollingUpdateNestedImpl(io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy item) {
      this.builder = new io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder(this, item);
    }
    RollingUpdateNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder builder;
    public N and() {
      return (N) StatefulSetUpdateStrategyFluentImpl.this.withRollingUpdate(builder.build());
    }
    public N endRollingUpdate() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apps-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetUpdateStrategyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class StatefulSetUpdateStrategyFluentImpl<A extends io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent<A>{
  public StatefulSetUpdateStrategyFluentImpl() {
  }
  public StatefulSetUpdateStrategyFluentImpl(io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategy instance) {
    this.withRollingUpdate(instance.getRollingUpdate()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder rollingUpdate;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRollingUpdate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy getRollingUpdate() {
    return this.rollingUpdate!=null?this.rollingUpdate.build():null;
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy buildRollingUpdate() {
    return this.rollingUpdate!=null?this.rollingUpdate.build():null;
  }
  public A withRollingUpdate(io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy rollingUpdate) {
    _visitables.get("rollingUpdate").remove(this.rollingUpdate);
    if (rollingUpdate!=null){ this.rollingUpdate= new io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder(rollingUpdate); _visitables.get("rollingUpdate").add(this.rollingUpdate);} return (A) this;
  }
  public java.lang.Boolean hasRollingUpdate() {
    return this.rollingUpdate != null;
  }
  public A withNewRollingUpdate(java.lang.Integer partition) {
    return (A)withRollingUpdate(new RollingUpdateStatefulSetStrategy(partition));
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate() {
    return new io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluentImpl.RollingUpdateNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy item) {
    return new io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluentImpl.RollingUpdateNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate() {
    return withNewRollingUpdateLike(getRollingUpdate());
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate() {
    return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy item) {
    return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StatefulSetUpdateStrategyFluentImpl that = (StatefulSetUpdateStrategyFluentImpl) o;
    if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rollingUpdate,  type,  additionalProperties,  super.hashCode());
  }
  public class RollingUpdateNestedImpl<N> extends io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyFluentImpl<io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>> implements io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    RollingUpdateNestedImpl(io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategy item) {
      this.builder = new io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder(this, item);
    }
    RollingUpdateNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apps.RollingUpdateStatefulSetStrategyBuilder builder;
    public N and() {
      return (N) StatefulSetUpdateStrategyFluentImpl.this.withRollingUpdate(builder.build());
    }
    public N endRollingUpdate() {
      return and();
    }
    
  }
  
}
